@@ -1,4 +1,4 @@
-########################################################################
+###############################################################################
 #       __  _____________       _       ______
 #      /  |/  / ____/ __ \_____(_)   __/ ____/
 #     / /|_/ / / __/ / / / ___/ / | / / __/
@@ -7,21 +7,20 @@
 #
 #   MGDrivE Auxiliary
 #   Marshall Lab
-#   November 2017
+#   jared_bennett@berkeley.edu
+#   December 2019
 #
-########################################################################
-
-
-########################################################################
+###############################################################################
+#######################################
 # Calculate Parameter Values
-########################################################################
+#######################################
 
 #' Solve for Omega (additional genotype-specific mortality)
 #'
 #' Solves for root of equation of geometrically-distributed lifespan for value of omega.
 #'
-#' @param mu daily mortality probability (discrete-time hazard, called \code{muAd} in code)
-#' @param lifespanReduction percent reduction in lifespan from average lifespan
+#' @param mu Daily mortality probability (discrete-time hazard, called \code{muAd} in code)
+#' @param lifespanReduction Target reduced lifespan, between 0 and 1
 #' (target average lifespan will be \eqn{\frac{1}{\mu_{Ad}} \times lifespanReduction})
 #'
 #' @importFrom stats uniroot
@@ -29,33 +28,35 @@
 #' @examples
 #' # reduce lifespan by 10%
 #' #  Example mu is an average for Aedes
-#' newOmega <- getOmega(mu = 0.11, lifespanReduction = 0.90)
+#' newOmega <- calcOmega(mu = 0.11, lifespanReduction = 0.90)
 #'
 #' @export
-getOmega <- function(mu, lifespanReduction){
+calcOmega <- function(mu, lifespanReduction){
 
+  # safety check
   if(lifespanReduction > 1 | lifespanReduction < 0){
     stop("parameter 'lifespanReduction' must be in interval [0,1]")
   }
 
   lifespan <- (1/mu) * lifespanReduction
 
-  getOmega_f <- function(omega,mu,lifespan){
+  calcOmega_f <- function(omega, mu, lifespan){
     (1/(1-omega+(omega*mu)))-lifespan
   }
 
-  return(uniroot(f=getOmega_f,interval=c(0,1),lifespan=lifespan,mu=mu,maxiter=1e4)$root)
+  return(uniroot(f=calcOmega_f, interval=c(0,1), lifespan=lifespan,
+                 mu=mu,maxiter=1e4)$root)
 }
 
-########################################################################
+#######################################
 # Delete files in a directory
-########################################################################
+#######################################
 
 #' Erase all files in a directory
 #'
-#' Given a directory path, check it exists and if so delete all its contents.
+#' Given a directory path, check that it exists, and if so, delete all its contents.
 #'
-#' @param directory directory whose contents will be deleted
+#' @param directory Directory whose contents will be deleted
 #' @param verbose Chatty? Default is TRUE
 #'
 #' @examples
@@ -70,26 +71,82 @@ getOmega <- function(mu, lifespanReduction){
 #'
 #' @export
 eraseDirectory <- function(directory, verbose = TRUE){
+
   # check directory exists
   if(!dir.exists(directory)){
     if(verbose){cat("no such directory exists\n")}
-    return(NULL)
   }
+
+  # list files/subdirectories to delete
   dirFiles = list.files(path = directory)
-  # begin deleting contents
+
+  # delete contents
   if(length(dirFiles)>0){
       for(i in dirFiles){
         if(verbose){cat("removing file: ",file.path(directory, i),"\n", sep = "")}
-        #file.remove(file.path(directory, i))
         unlink(x = file.path(directory, i), recursive = TRUE)
       }
   }
-  # end deleting contents
+
 }
 
-########################################################################
+#######################################
+# Population Objects
+#######################################
+
+#' Normalise a Numeric Vector
+#'
+#' Normalise a numeric vector to sum to one
+#'
+#' @param vector Numeric vector
+#'
+normalise <- function(vector){
+  if(all(vector==0)){
+    return(vector)
+  } else {
+    return(vector/sum(vector))
+  }
+}
+
+#######################################
+# Kernel-related
+#######################################
+
+#' Calculates the zero-inflation part of a hurdle exponential kernel.
+#'
+#' Given the probability of an adult mosquito to stay in the same patch throughout
+#' its whole lifespan, and its mortality, it calculates the height of the pulse-density
+#' part of the hurdle kernel.
+#'
+#' @param stayThroughLifespanProbability Probability of a mosquito to spend its
+#' whole lifespan in the same node
+#' @param adultMortality Adult mortality rate
+#'
+#' @examples
+#' # setup distance matrix
+#' # two-column matrix with latitude/longitude, in degrees
+#' latLong = cbind(runif(n = 5, min = 0, max = 90),
+#'                 runif(n = 5, min = 0, max = 180))
+#'
+#' # Vincenty Ellipsoid  distance formula
+#' distMat = calcVinEll(latLongs = latLong)
+#'
+#' # get hurdle height
+#' # Lets assume 80% stay probs and adult mortality of 0.1
+#' hHeight <- calcZeroInflation(stayThroughLifespanProbability = 0.80,
+#'                              adultMortality = 0.1)
+#'
+#' # calculate hurdle exponential distribution over distances
+#' kernMat = calcHurdleExpKernel(distMat = distMat, rate = 10, p0 = hHeight)
+#'
+#' @export
+calcZeroInflation <- function(stayThroughLifespanProbability,adultMortality){
+  return(stayThroughLifespanProbability^(adultMortality))
+}
+
+#######################################
 # Post-processing of Output
-########################################################################
+#######################################
 
 #' Split Output by Patch
 #'
@@ -98,11 +155,9 @@ eraseDirectory <- function(directory, verbose = TRUE){
 #' @param readDir Directory where output was written to
 #' @param writeDir Directory to write output to. Default is readDir
 #' @param remFile Remove original output? Default is TRUE
-#' @param numCores How many cores to use when writing output. Default is 1
 #' @param verbose Chatty? Default is TRUE
 #'
-#' @import data.table
-#' @importFrom utils setTxtProgressBar txtProgressBar
+#' @importFrom utils setTxtProgressBar txtProgressBar write.table
 #'
 #' @examples
 #' \dontrun{
@@ -112,23 +167,17 @@ eraseDirectory <- function(directory, verbose = TRUE){
 #' oPath <- "path/to/write/output"
 #'
 #' # split data by patch, keep original files
-#' #  not return value
-#' #  numCores uses data.table::setDTthreads internally
-#' splitOutput(readDir = fPath, writeDir = oPath, remFile = FALSE, numCores = 1)
+#' #  no return value
+#' splitOutput(readDir = fPath, writeDir = oPath, remFile = FALSE)
 #'
 #' # Alternatively, remove the original files and write new ones in their place
 #' fPath <- "path/to/data/containing/folder"
 #'
-#' splitOutput(readDir = fPath, writeDir = NULL, remFile = TRUE, numCores = 1)
+#' splitOutput(readDir = fPath, writeDir = NULL, remFile = TRUE)
 #' }
 #'
 #' @export
-splitOutput <- function(readDir, writeDir=NULL, remFile=TRUE, numCores=1, verbose=TRUE){
-
-  # Set data.table thread use.
-  oldThread = data.table::getDTthreads(verbose = FALSE)
-  data.table::setDTthreads(threads = numCores)
-  on.exit(expr = data.table::setDTthreads(threads = oldThread))  # Reset data.table thread use.
+splitOutput <- function(readDir, writeDir=NULL, remFile=TRUE, verbose=TRUE){
 
   # get all files in the read directory
   dirFiles = list.files(path = readDir, pattern = "^[MF]_.*\\.csv$", full.names = TRUE)
@@ -137,37 +186,55 @@ splitOutput <- function(readDir, writeDir=NULL, remFile=TRUE, numCores=1, verbos
   if(is.null(writeDir)){writeDir <- readDir}
 
   # initialize text, progress bar below
-  if(verbose){cat("  Splitting", length(dirFiles), "files.\n")}
-  if(remFile){
-    if(verbose){cat("  Removing original files.\n")}
-  } else {
-    if(verbose){cat("  Not removing original files.\n\n")}
+  if(verbose){
+    # what we're doing
+    cat("  Splitting", length(dirFiles), "files.\n")
+
+    # whether or not we remove files
+    if(remFile){
+      cat("  Removing original files.\n")
+    } else {
+      cat("  Not removing original files.\n\n")
+    }
   }
 
   # loop over files
   for(selectFile in dirFiles){
 
     # Read in files
-    fileIn = data.table::fread(input = selectFile, sep = ",",
-                               header = TRUE, verbose = FALSE, showProgress = FALSE,
-                               data.table = TRUE, logical01 = FALSE)
+    columnNames <- scan(file = selectFile, what = character(), sep = ",",
+                        nlines = 1, quiet = TRUE)
+    fileIn = matrix(data = scan(file = selectFile, what = numeric(), sep = ",",
+                                skip = 1, quiet = TRUE),
+                    ncol = length(columnNames), byrow = TRUE,
+                    dimnames = list(NULL, columnNames))
+
+    # get stuff for loop
+    patches <- unique(fileIn[ ,2])
+    patchRows <- seq.int(from = 1, to = dim(fileIn)[1], by = length(patches))
+    fileBase <- strsplit(x = basename(path = selectFile), split = ".", fixed = TRUE)[[1]][1]
 
     # progress bar stuff
     if(verbose){
-      pb = txtProgressBar(min = 0,max = length(unique(fileIn$Patch)),style = 3)
+      pb = txtProgressBar(min = 0,max = length(patches),style = 3)
     }
     pbVal = 0
 
     # loop over patches, split and write out
-    for(patch in unique(fileIn$Patch)){
+    for(patch in patches){
 
-      patchName = sub(pattern = ".csv",
-                      replacement = paste0("_Patch",formatC(x = patch, width = 3, format = "d", flag = "0"),".csv"),
-                      x = selectFile, fixed = TRUE)
+      # output file name
+      patchName = file.path(writeDir, paste0(fileBase, "_Patch",
+                                             formatC(x = patch, width = 3, format = "d", flag = "0"),
+                                             ".csv") )
 
-      data.table::fwrite(x = fileIn[Patch==patch][ ,Patch:=NULL],
-                         file = patchName, logical01 = FALSE,
-                         showProgress = FALSE, verbose = FALSE)
+      # write output
+      #  subset matrix by patch number, then remove patch label column
+      write.table(x = fileIn[patchRows, ][ ,-2], file = patchName, sep = ",",
+                  row.names = FALSE, col.names = TRUE)
+
+      # increment rows
+      patchRows[] <- patchRows + 1L
 
       # some indication that it's working
       pbVal = pbVal+1
@@ -189,9 +256,9 @@ splitOutput <- function(readDir, writeDir=NULL, remFile=TRUE, numCores=1, verbos
 #' @param writeDir Directory to write output to. Default is readDir
 #' @param genotypes Character vector of possible genotypes; found in \code{driveCube$genotypesID}
 #' @param remFile Boolean flag to remove original (unaggregated) file
-#' @param numCores Number of cores when reading/writing. Default is 1.
 #' @param verbose Chatty? Default is TRUE
 #'
+#'
 #' @examples
 #' \dontrun{
 #' # This example assumes user has already run MGDrivE and generated output.
@@ -207,23 +274,13 @@ splitOutput <- function(readDir, writeDir=NULL, remFile=TRUE, numCores=1, verbos
 #' cube <- cubeMendelian()
 #'
 #' # no return value from function
-#' # numCores uses data.table::setDTthreads internally
-#' aggregateFemales(readDir= fPath, writeDi = NULL, genotypes = cube$genotypesID,
-#'                  remFile = FALSE, numCores = 1)
+#' aggregateFemales(readDir= fPath, writeDir = NULL, genotypes = cube$genotypesID,
+#'                  remFile = TRUE)
 #' }
 #'
 #' @export
-aggregateFemales <- function(readDir, writeDir=NULL, genotypes, remFile=FALSE,
-                             numCores=1, verbose=TRUE){
-
-  # Set data.table thread use.
-  oldThread = data.table::getDTthreads(verbose = FALSE)
-  data.table::setDTthreads(threads = numCores)
-  on.exit(expr = data.table::setDTthreads(threads = oldThread))  # Reset data.table thread use.
-
-  #if the computer has the just-in-time compiler, it makes a huge difference in
-  # string searches
-  if(pcre_config()["JIT"]){options(PCRE_use_JIT = TRUE)}
+aggregateFemales <- function(readDir, writeDir=NULL, genotypes, remFile=TRUE,
+                             verbose=TRUE){
 
   # check write directory
   if(is.null(writeDir)){writeDir <- readDir}
@@ -232,42 +289,49 @@ aggregateFemales <- function(readDir, writeDir=NULL, genotypes, remFile=FALSE,
   femaleFiles = list.files(path = readDir, pattern = "^F_.*\\.csv$", full.names = TRUE)
 
   # initialize progress bar and text
-  if(verbose){cat("  Aggregating", length(femaleFiles), "files.\n")}
-  if(remFile){
-    if(verbose){cat("  Removing original files.\n")}
-  } else {
-    if(verbose){cat("  Not removing original files.\n\n")}
-  }
-
   if(verbose){
+    # what we're doing
+    cat("  Aggregating", length(femaleFiles), "files.\n")
+
+    # whether or not we remove shit
+    if(remFile){
+      cat("  Removing original files.\n")
+    } else {
+      cat("  Not removing original files.\n\n")
+    }
+
+    # progress bar
     pb = txtProgressBar(min = 0,max = length(femaleFiles),style = 3)
   }
   pbVal = 0
 
+
+  # setup aggregation columns
+  #  +1 offset for time column
+  nGenos <- length(genotypes)
+  idxList <- lapply(X = 0:(nGenos-1) * nGenos, FUN = "+", 2:(nGenos+1))
+
+
   #loop over files
   for(selectFile in femaleFiles){
 
-
     #read in file
-    thisOutput =  data.table::fread(input = selectFile, sep = ",",
-                                   header = TRUE, verbose = FALSE, showProgress = FALSE,
-                                   data.table = TRUE, logical01 = FALSE)
-
-    #get time/patch and remove from data.table
-    timePatch = thisOutput[,"Time"] # this keeps object type too, useful later
-    thisOutputNames = names(thisOutput)
+    thisOutput = matrix(data = scan(file = selectFile, what = numeric(), sep = ",", skip = 1, quiet = TRUE),
+                        ncol = 1+nGenos^2, byrow = TRUE)
 
     #aggregate output
-    aggregateOut = vapply(X = genotypes,FUN = function(x){
-      cols = grep(pattern = paste0("^", x), x = thisOutputNames, perl = TRUE)
-      thisOutput[, rowSums(.SD), .SDcols = cols]
-    },FUN.VALUE = numeric(nrow(thisOutput)))
+    aggregateOut = vapply(X = idxList, FUN = function(x){
+      rowSums(x = thisOutput[ ,x])
+    }, FUN.VALUE = numeric(nrow(thisOutput)))
 
     #name file and write out
-    fileName = sub(pattern = "_",replacement = "_Aggregate_",x = selectFile, fixed = TRUE)
-    data.table::fwrite(x = cbind(timePatch,aggregateOut),
-                       file = fileName, logical01 = FALSE,
-                       showProgress = FALSE, verbose = FALSE)
+    fileName <- file.path(writeDir, sub(pattern = "_",replacement = "_Aggregate_",
+                                        x = basename(path = selectFile), fixed = TRUE)
+    )
+
+    # combine time column from original file, with aggregated matrix of female counts
+    write.table(x = cbind(thisOutput[ ,1],aggregateOut), file = fileName,
+                sep = ",", row.names = FALSE, col.names = c("Time",genotypes))
 
     # check if removing file
     if(remFile){file.remove(selectFile)}
@@ -293,7 +357,6 @@ aggregateFemales <- function(readDir, writeDir=NULL, genotypes, remFile=FALSE,
 #' @param readDir Directory where output was written to
 #' @param writeDir Directory to write output to. Default is one level above readDir
 #'
-#' @importFrom utils write.csv
 #'
 #' @examples
 #' \dontrun{
@@ -306,11 +369,12 @@ aggregateFemales <- function(readDir, writeDir=NULL, genotypes, remFile=FALSE,
 #'
 #' # first, split output by patch and aggregate females by mate genotype
 #' # remember, cube is for example and changes with simulation
+#' #  landscape aggregation will work if females are not aggregated, but it's slower
 #' cube <- cubeMendelian()
 #'
-#' splitOutput(readDir = fPath, writeDir = NULL, remFile = TRUE, numCores = 1)
+#' splitOutput(readDir = fPath, writeDir = NULL, remFile = TRUE)
 #' aggregateFemales(readDir= fPath, writeDi = NULL, genotypes = cube$genotypesID,
-#'                  remFile = FALSE, numCores = 1)
+#'                  remFile = TRUE)
 #'
 #' # aggregate mosquitoes over entire landscape
 #' #  no return value
@@ -344,43 +408,51 @@ aggregateOutput <- function(readDir, writeDir=NULL){
   fMat <- matrix(data = scan(file = fFiles[1], what = integer(), sep = ",", skip = 1, quiet = TRUE),
                  ncol = length(columnNames), byrow = TRUE, dimnames = list(NULL,columnNames))
 
+  # set things to reuse
+  nRowM <- dim(mMat)[1]
+  nColM <- dim(mMat)[2]
+  nRowF <- dim(fMat)[1]
+  nColF <- dim(fMat)[2]
+  nReadM <- nRowM * nColM
+  nReadF <- nRowF * nColF
+  simTime <- mMat[ ,"Time"]
 
   # aggregate files
   for(sFile in 2:length(mFiles)){
 
     # males
-    mMat <- mMat + matrix(data = scan(file = mFiles[sFile], what = integer(), sep = ",", skip = 1, quiet = TRUE),
-                          ncol = length(columnNames), byrow = TRUE, dimnames = list(NULL,columnNames))
+    mMat <- mMat + matrix(data = scan(file = mFiles[sFile], what = integer(),
+                                      sep = ",", skip = 1, n = nReadM, quiet = TRUE),
+                          nrow = nRowM, ncol = nColM, byrow = TRUE)
 
     # females
-    fMat <- fMat + matrix(data = scan(file = fFiles[sFile], what = integer(), sep = ",", skip = 1, quiet = TRUE),
-                          ncol = length(columnNames), byrow = TRUE, dimnames = list(NULL,columnNames))
+    fMat <- fMat + matrix(data = scan(file = fFiles[sFile], what = integer(),
+                                      sep = ",", skip = 1, n = nReadF, quiet = TRUE),
+                          nrow = nRowF, ncol = nColF, byrow = TRUE)
 
   } # end loop over files
 
   # fix time addition
-  mMat[ ,1] <- fMat[ ,1] <- 1:dim(mMat)[1]
+  mMat[ ,1] <- fMat[ ,1] <- simTime
 
   # print males
   fileName <- file.path(writeDir, file.path("M_LandscapeAgg_Run", hold[length(hold)], ".csv", fsep = ""))
-  write.csv(x = mMat, file = fileName, row.names = FALSE)
+  write.table(x = mMat, file = fileName, sep = ",", row.names = FALSE, col.names = TRUE)
 
   # print females
   fileName <- file.path(writeDir, file.path("F_LandscapeAgg_Run", hold[length(hold)], ".csv", fsep = ""))
-  write.csv(x = fMat, file = fileName, row.names = FALSE)
+  write.table(x = fMat, file = fileName, sep = ",", row.names = FALSE, col.names = TRUE)
 
 } # end aggregate over landscape
 
 
-
-
 #' Retrieve Output
 #'
 #' Read in output from directory. The resulting object will be a nested list;
 #' outermost nesting dimension indexes runID, within runID elements are split by sex
 #' and innermost nesting is over patches.
 #'
-#' @param readDir directory where output was written to; must not end in path separator
+#' @param readDir Directory where output was written to; must not end in path separator
 #' @param verbose Chatty? Default is TRUE
 #'
 #' @importFrom utils read.csv
@@ -398,7 +470,6 @@ aggregateOutput <- function(readDir, writeDir=NULL){
 #' dataList <- retrieveOutput(readDir = fPath)
 #' }
 #'
-#'
 #' @return Nested List
 #'
 #' @export
@@ -471,7 +542,6 @@ retrieveOutput <- function(readDir, verbose=TRUE){
 #' @param writeDir Directory to write output
 #' @param mean Boolean, calculate mean or not. Default is TRUE
 #' @param quantiles Vector of quantiles to calculate. Default is NULL
-#' @param numCores Number of cores when reading/writing. Default is 1.
 #' @param verbose Chatty? Default is TRUE
 #'
 #' @examples
@@ -487,58 +557,52 @@ retrieveOutput <- function(readDir, verbose=TRUE){
 #' # here, only calculate mean, no quantiles
 #' #  no return value
 #' calcQuantiles(readDir = fPath, writeDir = oPath, mean = TRUE,
-#'               quantiles = NULL, numCores = 1)
+#'               quantiles = NULL)
 #'
 #' # here, calculate 2.5% and 97.5% quantiles
 #' calcQuantiles(readDir = fPath, writeDir = oPath, mean = FALSE,
-#'               quantiles = c(0.025, 0.975), numCores = 1)
+#'               quantiles = c(0.025, 0.975))
 #' }
 #'
 #' @return Writes output to files in writeDir
 #' @export
 calcQuantiles <- function(readDir, writeDir, mean=TRUE, quantiles=NULL,
-                          numCores=1, verbose=TRUE){
+                          verbose=TRUE){
 
-  #safety check
+  # safety check
   if(!mean && is.null(quantiles)){
     stop("User needs to specify the mean or which quantiles to calculate. ")
   }
 
-  # Set data.table thread use.
-  oldThread = data.table::getDTthreads(verbose = FALSE)
-  data.table::setDTthreads(threads = numCores)
-  on.exit(expr = data.table::setDTthreads(threads = oldThread))  # Reset data.table thread use.
+  # get all files
+  patchFiles <- lapply(X = list.dirs(path = readDir, full.names = TRUE, recursive = FALSE),
+                       FUN = list.files, pattern = "^[FM].*\\.csv$", full.names = TRUE)
 
-  #get files
-  repFiles = list.dirs(path = readDir, full.names = TRUE, recursive = FALSE)
-  patchFiles = lapply(X = repFiles, FUN = list.files, pattern = "^[FM].*\\.csv$")
-
-  #subset females/males
+  #s ubset females/males
   malePatches <- lapply(X = patchFiles, FUN = grep, pattern = "M_", fixed = TRUE, value=TRUE)
   femalePatches <- lapply(X = patchFiles, FUN = grep, pattern = "F_Aggregate", fixed = TRUE, value=TRUE)
 
-  #generate a list of all patches to run over
+  # generate a list of all patches to run over
   patchList = unique(regmatches(x = patchFiles[[1]],
                                 m = regexpr(pattern = "Patch[0-9]+",
                                             text = patchFiles[[1]],
                                             perl = TRUE)))
 
-  #read in a file initially to get variables and setup return array
-  testFile <- data.table::fread(input = file.path(repFiles[1], patchFiles[[1]][1]),
-                                header = TRUE, verbose = FALSE, showProgress = FALSE,
-                                logical01 = FALSE, sep = ",", drop = "Time")
+  # read in a file initially to get variables and setup return array
+  testFile <- read.csv(file = patchFiles[[1]][1], header = TRUE)
 
-  #bunch of constants that get used several times
-  numReps <- length(repFiles)
-  columnNames <- c("Time", names(testFile))
+  # bunch of constants that get used several times
+  numReps <- length(patchFiles)
+  columnNames <- names(testFile)
   numRow <- dim(testFile)[1]
-  numCol <- dim(testFile)[2]+1
+  numCol <- dim(testFile)[2]
+  numRead <- numRow*numCol
 
-  #setup input data holder
+  # setup input data holder
   popDataMale <- array(data = 0, dim = c(numRow,  numReps, numCol-1))
   popDataFemale <- array(data = 0, dim = c(numRow, numReps, numCol-1))
 
-  #setup output data holder
+  # setup output data holder
   if(is.null(quantiles)){
     outputDataMale <- array(data = 0, dim = c(numRow, numCol, 1),
                             dimnames = list(NULL, columnNames, NULL))
@@ -550,23 +614,25 @@ calcQuantiles <- function(readDir, writeDir, mean=TRUE, quantiles=NULL,
     outputDataFemale <- array(data = 0, dim = c(numRow, numCol, length(quantiles)),
                               dimnames = list(NULL, columnNames, NULL))
   }
-  outputDataMale[,1,] <- 1:numRow
-  outputDataFemale[,1,] <- 1:numRow
 
+  # set time from testFile
+  outputDataMale[,1,] <- testFile[ ,"Time"]
+  outputDataFemale[,1,] <- testFile[ ,"Time"]
 
   # write initial outputs and setup progress bar
-  if(verbose){cat("  Patches:", length(malePatches[[1]]), "\n")}
-  if(verbose){cat("  Repetitions:", numReps, "\n\n")}
-
   if(verbose){
-    pb = txtProgressBar(min = 0,max = length(malePatches),style = 3)
+    # how many patches and repetitions are we running through
+    cat("  Patches:", length(patchList), "\n  Repetitions:", numReps, "\n\n")
+
+    # setup progress bar
+    pb = txtProgressBar(min = 0,max = length(patchList),style = 3)
   }
   pbVal = 0
 
 
-  #loop over all patches and do stats.
+  # loop over all patches and do stats.
   for(patch in patchList){
-    #get male and female files, all repetitions of this patch
+    # get male and female files, all repetitions of this patch
     maleFiles <- vapply(X = malePatches,
                         FUN = grep, pattern = patch, fixed=TRUE, value=TRUE,
                         FUN.VALUE = character(length = 1L))
@@ -576,44 +642,43 @@ calcQuantiles <- function(readDir, writeDir, mean=TRUE, quantiles=NULL,
                           FUN.VALUE = character(length = 1L))
 
 
-    #Read in all repetitions for this patch
+    # read in all repetitions for this patch
+    #  remove time column after reading in.
     for(repetition in 1:numReps){
-      popDataMale[ ,repetition, ] <- as.matrix(data.table::fread(input = file.path(repFiles[repetition], maleFiles[repetition]),
-                                                                 header = TRUE, verbose = FALSE, showProgress = FALSE,
-                                                                 logical01 = FALSE, sep = ",", drop = "Time"))
-      popDataFemale[ ,repetition, ] <- as.matrix(data.table::fread(input = file.path(repFiles[repetition], femaleFiles[repetition]),
-                                                                   header = TRUE, verbose = FALSE, showProgress = FALSE,
-                                                                   logical01 = FALSE, sep = ",", drop = "Time"))
+      popDataMale[ ,repetition, ] <- matrix(data = scan(file = maleFiles[repetition],
+                                                        what = numeric(), n = numRead,
+                                                        sep = ",", skip = 1, quiet = TRUE),
+                                            nrow = numRow, ncol = numCol, byrow = TRUE)[ ,-1]
+
+      popDataFemale[ ,repetition, ] <- matrix(data = scan(file = femaleFiles[repetition],
+                                                          what = numeric(), n = numRead,
+                                                          sep = ",", skip = 1, quiet = TRUE),
+                                              nrow = numRow, ncol = numCol, byrow = TRUE)[ ,-1]
     }
 
-
-    #if the user wants the mean, calculate and put out.
+    # if the user wants the mean, calculate and put out.
     if(mean){
       for(whichCol in 1:(numCol-1)){
         outputDataMale[ ,whichCol+1,1] <- .rowMeans(x = popDataMale[ , ,whichCol],
-                                                           m = numRow, n = numReps)
+                                                    m = numRow, n = numReps)
         outputDataFemale[ ,whichCol+1,1] <- .rowMeans(x = popDataFemale[ , ,whichCol],
-                                                             m = numRow, n = numReps)
+                                                      m = numRow, n = numReps)
       }
 
-      #write output
+      # write output
       maleFileName <- file.path(writeDir,
-                                file.path("M_Mean_", patch, ".csv", fsep = "")
-      )
+                                file.path("M_Mean_", patch, ".csv", fsep = "") )
       femaleFileName <- file.path(writeDir,
-                                  file.path("F_Mean_", patch, ".csv", fsep = "")
-      )
+                                  file.path("F_Mean_", patch, ".csv", fsep = "") )
 
-      data.table::fwrite(x = as.data.frame(outputDataMale[ , ,1]),
-                         file = maleFileName, verbose = FALSE,
-                         showProgress = FALSE, logical01 = FALSE)
-      data.table::fwrite(x = as.data.frame(outputDataFemale[ , ,1]),
-                         file = femaleFileName, verbose = FALSE,
-                         showProgress = FALSE, logical01 = FALSE)
-    }#end mean
+      write.table(x = outputDataMale[ , ,1], file = maleFileName, sep = ",",
+                  row.names = FALSE, col.names =TRUE)
+      write.table(x = outputDataFemale[ , ,1], file = femaleFileName, sep = ",",
+                  row.names = FALSE, col.names =TRUE)
+    } # end mean
 
 
-    #if the user wants quantiles, do them and write output
+    # if the user wants quantiles, do them and write output
     if(!is.null(quantiles)){
       for(whichCol in 1:(numCol-1)){
         outputDataMale[ ,whichCol+1, ] <- quantileC(Trials = popDataMale[ , ,whichCol],
@@ -624,174 +689,34 @@ calcQuantiles <- function(readDir, writeDir, mean=TRUE, quantiles=NULL,
 
       }#end loop to calculate quantiles
 
-      #write output
+      # write output
       for(whichQuant in 1:length(quantiles)){
-        #file names
+        # file names
         maleFileName <- file.path(writeDir,
                                   file.path("M_Quantile_",
                                             formatC(x = quantiles[whichQuant], digits = 4,
                                                     format = "f", decimal.mark = "",
                                                     big.mark = NULL),
-                                            "_", patch, ".csv", fsep = "")
-        )
+                                            "_", patch, ".csv", fsep = "") )
         femaleFileName <- file.path(writeDir,
                                     file.path("F_Quantile_",
                                               formatC(x = quantiles[whichQuant], digits = 4,
                                                       format = "f", decimal.mark = "",
                                                       big.mark = NULL),
-                                              "_", patch, ".csv", fsep = "")
-        )
+                                              "_", patch, ".csv", fsep = "") )
 
-        #write output
-        data.table::fwrite(x = as.data.frame(outputDataMale[ , ,whichQuant]),
-                           file = maleFileName, verbose = FALSE,
-                           showProgress = FALSE, logical01 = FALSE)
-        data.table::fwrite(x = as.data.frame(outputDataFemale[ , ,whichQuant]),
-                           file = femaleFileName, verbose = FALSE,
-                           showProgress = FALSE, logical01 = FALSE)
-      }#end loop to write files
-    }#end quantiles
+        # write output
+        write.table(x = outputDataMale[ , ,whichQuant], file = maleFileName, sep = ",",
+                    row.names = FALSE, col.names =TRUE)
+        write.table(x = outputDataFemale[ , ,whichQuant], file = femaleFileName, sep = ",",
+                    row.names = FALSE, col.names =TRUE)
+      } # end loop to write files
+    } # end quantiles
 
     # some indication that it's working
     pbVal = pbVal+1
     if(verbose){setTxtProgressBar(pb = pb, value = pbVal)}
 
-  }#end loop over patches
+  } # end loop over patches
 
-}#end function
-
-########################################################################
-# Population Objects
-########################################################################
-
-#' Normalise a Numeric Vector
-#'
-#' Normalise a numeric vector to sum to one
-#'
-#' @param vector numeric vector
-#'
-normalise <- function(vector){
-  if(all(vector==0)){
-    return(vector)
-  } else {
-    return(vector/sum(vector))
-  }
-}
-
-#' Create a Named Vector
-#'
-#' Create a named vector of 0s
-#'
-#' @param genotypesID character vector of possible genotypes
-#'
-createNamedPopVector <- function(genotypesID){
-  out = rep(0,times=length(genotypesID))
-  names(out) = genotypesID
-  return(out)
-}
-
-#' Create a Named Matrix
-#'
-#' Create a named matrix of 0s
-#'
-#' @param genotypesID character vector of possible genotypes
-#'
-createNamedPopMatrix <- function(genotypesID){
-  return(
-    matrix(data=0,nrow=length(genotypesID),ncol=length(genotypesID),dimnames=list(genotypesID,genotypesID))
-  )
-}
-
-#' Create a population array of vectors
-#'
-#' Creates an array for the population history to be stored. The length of the
-#' array is equal to the window required for the model to run
-#' (in our specific case it is equal to the sum of aquatic stages lengths).
-#'
-#' @param genotypesID character vector of possible genotypes
-#' @param memoryWindow integer size of list structure
-#'
-initPopVectorArray <- function(genotypesID,memoryWindow){
-  array=vector(mode="list",length=memoryWindow)
-  for(i in 1:length(array)){array[[i]]=createNamedPopVector(genotypesID)}
-  return(array)
-}
-
-#' Create a population array of matrices
-#'
-#' Creates an array for the population history to be stored. The length of the
-#' array is equal to the window required for the model to run
-#' (in our specific case it is equal to the sum of aquatic stages lengths).
-#'
-#' @param genotypesID character vector of possible genotypes
-#' @param memoryWindow integer size of list structure
-#'
-initPopMatrixArray <- function(genotypesID,memoryWindow){
-  array=vector(mode="list",length=memoryWindow)
-  for(i in 1:length(array)){array[[i]]=createNamedPopMatrix(genotypesID)}
-  return(array)
-}
-
-#' Create a primed population array of vectors
-#'
-#' Primes an array for the population history to be stored. The length of the
-#' array is equal to the window required for the model to run
-#' (in our specific case it is equal to the sum of aquatic stages lengths).
-#'
-#' @param primingVector a named vector population
-#' @param memoryWindow integer size of list structure
-#'
-primePopVectorArray <- function(primingVector,memoryWindow){
-  array=vector(mode="list",length=memoryWindow)
-  for(i in 1:length(array)){array[[i]]=primingVector}
-  return(array)
-}
-
-#' Create a primed population array of matrices
-#'
-#' Primes an array for the population history to be stored. The length of the
-#' array is equal to the window required for the model to run
-#' (in our specific case it is equal to the sum of aquatic stages lengths).
-#'
-#' @param primingMatrix a named matrix population
-#' @param memoryWindow integer size of list structure
-#'
-primePopMatrixArray <- function(primingMatrix,memoryWindow){
-  array=vector(mode="list",length=memoryWindow)
-  for(i in 1:length(array)){array[[i]]=primingMatrix}
-  return(array)
-}
-
-########################################################################
-# Kernel-related
-########################################################################
-
-#' Calculates the zero-inflation part of a hurdle exponential kernel.
-#'
-#' Given the probability of an adult mosquito to stay in the same patch throughout its whole lifespan, and its mortality, it
-#' calculates the height of the pulse-density part of the hurdle kernel.
-#'
-#' @param stayThroughLifespanProbability Probability of a mosquito to spend its whole lifespan in the same node
-#' @param adultMortality Adult mortality rate
-#'
-#' @examples
-#' # setup distance matrix
-#' # two-column matrix with latitude/longitude, in degrees
-#' latLong = cbind(runif(n = 5, min = 0, max = 90),
-#'                 runif(n = 5, min = 0, max = 180))
-#'
-#' # Vincenty Ellipsoid  distance formula
-#' distMat = calcVinEll(latLongs = latLong)
-#'
-#' # get hurdle height
-#' # Lets assume 80% stay probs and adult mortality of 0.1
-#' hHeight <- calcZeroInflation(stayThroughLifespanProbability = 0.80,
-#'                              adultMortality = 0.1)
-#'
-#' # calculate hurdle exponential distribution over distances
-#' kernMat = calcHurdleExpKernel(distMat = distMat, rate = 10, p0 = hHeight)
-#'
-#' @export
-calcZeroInflation <- function(stayThroughLifespanProbability,adultMortality){
-  stayThroughLifespanProbability^(adultMortality)
-}
+} # end function
